<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-position="left">
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="业务类型" style="width: 100%;">
            <el-select v-model="queryParams.bizType" placeholder="请选择">
              <el-option
                  v-for="item in bizType"
                  :key="item.value"
                  :label="item.label"
                  :value="item.value">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>

        <el-col :span="6">
          <el-form-item label="请求时间" style="width: 100%;">
            <el-date-picker
                v-model="createTimes"
                value-format="YYYY-MM-DD"
                type="daterange"
                range-separator="-"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
            ></el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="请求结果" prop="result" style="width: 100%;">
            <el-input
                v-model="queryParams.result"
                placeholder="请输入请求结果"
                clearable
                @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="响应数据" prop="requestData" style="width: 100%;">
            <el-input
                v-model="queryParams.responseData"
                placeholder="请输入响应数据"
                clearable
                @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">


      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="Download"
          @click="handleExport"
          v-hasPermi="['apsWorkOrderJobLog:export']"
        >导出</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
            type="success"
            plain
            icon="Edit"
            :disabled="single"
            @click="handleUpdate"
            v-hasPermi="['apsWorkOrderJobLog:edit']"
        >查看</el-button>
      </el-col>

      <right-toolbar v-model:showSearch="showSearch"
        @queryTable="handleQuery"
        @resetTable="resetQuery"
      ></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :virtualYConfig="virtualYConfig"
        :columns="columns"
        :data="LogList"
        :loading="loading"
        :height="height" >
      <template #buttons="{row}">
        <vxe-button mode="text" @click="handleUpdate(row)" v-hasPermi="['apsWorkOrderJobLog:edit']" >查看</vxe-button>
      </template>
    </HxlhTable>

    <!-- 添加或修改工单同步日志对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="ApsWorkOrderJobLogRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="页码" prop="pageNum">
          <el-input v-model="form.pageNum"  :disabled="true" />
        </el-form-item>
        <el-form-item label="请求数量" prop="pageCount">
          <el-input v-model="form.pageCount"   :disabled="true" />
        </el-form-item>
        <el-form-item label="请求参数" prop="requestData">
          <el-input v-model="form.requestData"   type="textarea" :rows="4" :disabled="true" />
        </el-form-item>
        <el-form-item label="保存结果" prop="result">
          <el-input v-model="form.result"  type="textarea"  :rows="4"     :disabled="true" />
        </el-form-item>
        <el-form-item label="响应数据" prop="responseData">
          <el-input v-model="form.responseData" type="textarea" :rows="4"  :disabled="true" />
        </el-form-item>
        <el-form-item label="提交时间" prop="createTime">
          <el-input v-model="form.createTime"   :disabled="true" />
        </el-form-item>
        <el-form-item label="更新时间" prop="updateTime">
          <el-input v-model="form.updateTime"    :disabled="true" />
        </el-form-item>
        <el-form-item label="同步主键" v-show="false" prop="orderId">
          <el-input v-model="form.orderId" placeholder="请输入同步主键" />
        </el-form-item>

      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">重新同步</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="ApsWorkOrderJobLog">
import { list, get, syncWorkOrder,syncProcess } from "@/api/mainPlan/workOrderJobLog";
import {ref} from "vue";
import HxlhTable from "@/components/HxlhTable/index.vue";

const { proxy } = getCurrentInstance();
const height = ref(document.documentElement.clientHeight - 220 + "px;")
const virtualYConfig = {
  enabled: true,
  gt: 0
};
const LogList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const createTimes=ref([]);

const data = reactive({
  form: {},
  queryParams: {
    pageCount: null,
    responseData: null,
    result: null,
    orderId: null,
    requestData: null
  },
  rules: {
  }
});
const columns = ref([
  { type: 'checkbox', width: 60, align:"center"},

  { title: '业务类型', field:'bizType', width: 150 },
  { title: '页码', field:'pageNum', width: 80 },
  { title: '请求数量', field:'pageCount', width: 80 },
  { title: '请求参数', field:'requestData' },
  { title: '请求时间', field:'createTime', width: 150 },
  { title: '更新时间', field:'updateTime', width: 150 },
  { title: '请求结果', field:'result', width: 150 },
  { title: '响应数据', field:'responseData' },
  { title: '操作', width: 100, fixed:"right", slots: { default: 'buttons' } }
])
const bizType = ref([
  {value:'work_order',label:' work_order'},
  {value:'work_order_process',label:' work_order_process'}

]);

const { queryParams, form, rules } = toRefs(data);

/** 查询工单同步日志列表 */
function getList() {
  loading.value = true;
  queryParams.value.params = {};
  if (null != createTimes && '' !== createTimes) {
    queryParams.value.params["beginCreateTime"] = createTimes.value[0];
    queryParams.value.params["endCreateTime"] = createTimes.value[1];
  }
  list(queryParams.value).then(response => {
    LogList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    pageNum: null,
    pageCount: null,
    responseData: null,
    result: null,
    orderId: null,
    requestData: null
  };
  proxy.resetForm("ApsWorkOrderJobLogRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加工单同步日志";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value

    get(_id).then(response => {
      form.value = response.data;
      open.value = true;
      title.value = "查看工单同步日志";
    });


}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["ApsWorkOrderJobLogRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        debugger;
        if(form.value.bizType==="work_order"){
          syncWorkOrder(form.value).then(response => {
            proxy.$modal.msgSuccess("同步成功");
            open.value = false;
            getList();
          });
        }else if(form.value.bizType==="work_order_process") {
          syncProcess(form.value).then(response => {
            proxy.$modal.msgSuccess("同步成功");
            open.value = false;
            getList();
          });

        }else{
          proxy.$modal.msgSuccess("暂未实现");
        }
      }
    }
  });
}
/** 导出按钮操作 */
function handleExport() {
  proxy.download('log/ApsWorkOrderJobLog/export', {
    ...queryParams.value
  }, `ApsWorkOrderJobLog_${new Date().getTime()}.xlsx`)
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除工单同步日志编号为"' + _ids + '"的数据项？').then(function() {
    return delApsWorkOrderJobLog(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}


getList();
</script>
<style scoped>
.column-with-margin {
  margin-right: 0px;
}
</style>